==> oce_0.12.orig.tar.gz: oce-OCE-0.12/src/HLRTest/HLRTest_OutLiner.cxx <==
// Created on: 1995-04-05
// Created by: Christophe MARION
// Copyright (c) 1995-1999 Matra Datavision
// Copyright (c) 1999-2012 OPEN CASCADE SAS
//
// The content of this file is subject to the Open CASCADE Technology Public
// License Version 6.5 (the "License"). You may not use the content of this file
// except in compliance with the License. Please obtain a copy of the License
// at http://www.opencascade.org and read it completely before using this file.
//
// The Initial Developer of the Original Code is Open CASCADE S.A.S., having its
// main offices at: 1, place des Freres Montgolfier, 78280 Guyancourt, France.
//
// The Original Code and all software distributed under the License is
// distributed on an "AS IS" basis, without warranty of any kind, and the
// Initial Developer hereby disclaims all such warranties, including without
// limitation, any warranties of merchantability, fitness for a particular
// purpose or non-infringement. Please see the License for the specific terms
// and conditions governing the rights and limitations under the License.


#include <HLRTest_OutLiner.ixx>

//=======================================================================
//function : HLRTest_OutLiner
//purpose  : 
//=======================================================================

HLRTest_OutLiner::HLRTest_OutLiner (const TopoDS_Shape& S)
{
  myOutLiner = new HLRTopoBRep_OutLiner(S);
}

//=======================================================================
//function : DrawOn
//purpose  : 
//=======================================================================

void HLRTest_OutLiner::DrawOn (Draw_Display& dis) const 
{
}

//=======================================================================
//function : Copy
//purpose  : 
//=======================================================================

Handle(Draw_Drawable3D) HLRTest_OutLiner::Copy () const 
{
  Handle(HLRTest_OutLiner) O = 
    new HLRTest_OutLiner(myOutLiner->OriginalShape());
  return O;
}

//=======================================================================
//function : Dump
//purpose  : 
//=======================================================================

void HLRTest_OutLiner::Dump (Standard_OStream& S) const 
{
  S << "This is an outliner" << endl;
}

//=======================================================================
//function : Whatis
//purpose  : 
//=======================================================================

void HLRTest_OutLiner::Whatis (Draw_Interpretor& I) const 
{
  I << "outliner";
}

==> oce_0.15.orig.tar.gz: oce-OCE-0.15/src/HLRTest/HLRTest_OutLiner.cxx <==
// Created on: 1995-04-05
// Created by: Christophe MARION
// Copyright (c) 1995-1999 Matra Datavision
// Copyright (c) 1999-2014 OPEN CASCADE SAS
//
// This file is part of Open CASCADE Technology software library.
//
// This library is free software; you can redistribute it and / or modify it
// under the terms of the GNU Lesser General Public version 2.1 as published
// by the Free Software Foundation, with special exception defined in the file
// OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
// distribution for complete text of the license and disclaimer of any warranty.
//
// Alternatively, this file may be used under the terms of Open CASCADE
// commercial license or contractual agreement.

#include <HLRTest_OutLiner.ixx>

//=======================================================================
//function : HLRTest_OutLiner
//purpose  : 
//=======================================================================

HLRTest_OutLiner::HLRTest_OutLiner (const TopoDS_Shape& S)
{
  myOutLiner = new HLRTopoBRep_OutLiner(S);
}

//=======================================================================
//function : DrawOn
//purpose  : 
//=======================================================================

void HLRTest_OutLiner::DrawOn (Draw_Display& /*dis*/) const 
{
}

//=======================================================================
//function : Copy
//purpose  : 
//=======================================================================

Handle(Draw_Drawable3D) HLRTest_OutLiner::Copy () const 
{
  Handle(HLRTest_OutLiner) O = 
    new HLRTest_OutLiner(myOutLiner->OriginalShape());
  return O;
}

//=======================================================================
//function : Dump
//purpose  : 
//=======================================================================

void HLRTest_OutLiner::Dump (Standard_OStream& S) const 
{
  S << "This is an outliner" << endl;
}

//=======================================================================
//function : Whatis
//purpose  : 
//=======================================================================

void HLRTest_OutLiner::Whatis (Draw_Interpretor& I) const 
{
  I << "outliner";
}
